HC = require 'HardonCollider'

function generateHexPath(centerX, centerY, radius, orientation)
    orientation = orientation or "flatTop"
    local path = {}

    local angle
    for point=1, 6, 1 do
        if orientation == "flatTop" then
            angle = math.pi / 180 * 60*point
        elseif orientation == "pointyTop" then
            angle = math.pi / 180 * (60*point-30)
        end

        table.insert(path, centerX + radius * math.cos(angle))
        table.insert(path, centerY + radius * math.sin(angle))
    end


    return path
end

function love.load()
    circ = HC.circle(400, 300, 20)
    circ2 = HC.circle(400, 360, 20)

    hex1 = HC.polygon(unpack(generateHexPath(200, 150, 100, "flatTop")))
    hex2 = HC.polygon(unpack(generateHexPath(200, 250, 100, "flatTop")))

    circXSpeed = 0
    circYSpeed = 0
    circMaxSpeed = 350
    circAccel = 75

end

function love.update(dt)

    -- White Circle Movement
    if love.keyboard.isDown("w") then 
         circYSpeed = circYSpeed - circAccel
         if circYSpeed <= -circMaxSpeed then circYSpeed = -circMaxSpeed end
    elseif love.keyboard.isDown("s") then
        circYSpeed = circYSpeed + circAccel
        if circYSpeed >= circMaxSpeed then circYSpeed = circMaxSpeed end
    else
        if circYSpeed < 0 then circYSpeed = circYSpeed + circAccel end
        if circYSpeed > 0 then circYSpeed = circYSpeed - circAccel end
        if math.abs(circYSpeed) < circAccel then circYSpeed = 0 end
    end

    if love.keyboard.isDown("a") then 
         circXSpeed = circXSpeed - circAccel
         if circXSpeed <= -circMaxSpeed then circXSpeed = -circMaxSpeed end
    elseif love.keyboard.isDown("d") then
        circXSpeed = circXSpeed + circAccel
        if circXSpeed >= circMaxSpeed then circXSpeed = circMaxSpeed end
    else
        if circXSpeed < 0 then circXSpeed = circXSpeed + circAccel end
        if circXSpeed > 0 then circXSpeed = circXSpeed - circAccel end
        if math.abs(circXSpeed) < circAccel then circXSpeed = 0 end
    end

    circ:move(circXSpeed * dt, circYSpeed * dt)

    -- Red Circle Movement
    if love.keyboard.isDown('right') then circ2:move(350*dt, 0) end
    if love.keyboard.isDown('left') then circ2:move(-350*dt, 0) end
    if love.keyboard.isDown('up') then circ2:move(0, -350*dt) end
    if love.keyboard.isDown('down') then circ2:move(0, 350*dt) end

    -- Collision Detection + Response
    for shape, delta in pairs(HC.collisions(circ)) do
        circ:move(delta.x, delta.y)
    end

    for shape, delta in pairs(HC.collisions(circ2)) do
        circ2:move(delta.x, delta.y)
    end

end

function love.draw()
    circ:draw()

    love.graphics.setColor(1, 0, 0)
    circ2:draw()
    love.graphics.print("RED: No acceleration. Arrow keys to move", 0, 15)
    
    love.graphics.setColor(1, 1, 1)
    hex1:draw()
    hex2:draw()

    love.graphics.print("WHITE: Acceleration. WASD to move", 0, 0)
end